@@ -1,3 +1,4 @@
+from typing import Literal
 from pathlib import Path
 import os
 from pydantic import BaseSettings
@@ -86,7 +87,9 @@ class MagicSettings(BaseSettings):
     company_name: str = None
 
     # for stripe
-    stripe_api_key: str = None
+    stripe_api_key_sandbox: str = None
+    stripe_api_key_production: str = None
+    stripe_env: Literal["sandbox", "production"] = None
 
     # for sentry
     sentry_dsn: str = None
